@@ -2,9 +2,6 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"[.spatial.design" <-
-function (x, ...) 
-{
+"[.spatial.design" <- function(x, ...) {
     x$design[...]
 }
