@@ -2,9 +2,6 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"WD42d" <-
-function (x) 
-{
+"WD42d" <- function(x) {
     t(WD4(t(WD4(x))))
 }
