@@ -2,9 +2,6 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"WD42di" <-
-function (x) 
-{
+"WD42di" <- function(x) {
     WD4i(t(WD4i(t(x))))
 }
