@@ -2,10 +2,7 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"WD4i" <-
-function (x) 
-{
+"WD4i" <- function(x) {
     if (!is.matrix(x)) 
         x <- matrix(x, nrow = length(x), ncol = 1)
     n <- nrow(x)
