@@ -2,15 +2,14 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"draw.bplot.obj" <-
-function (obj, width, xpos, outlier = TRUE, horizontal = 
-FALSE,lwd=NA,col=NA) {
-#
-# fill in defaults if not specfied
-if( missing( lwd)) lwd<- par()$lwd
-if( missing( col)) lwd<- par()$col
-
+"draw.bplot.obj" <- function(obj, width, xpos, outlier = TRUE, 
+    horizontal = FALSE, lwd = NA, col = NA) {
+    #
+    # fill in defaults if not specfied
+    if (missing(lwd)) 
+        lwd <- par()$lwd
+    if (missing(col)) 
+        lwd <- par()$col
     N <- obj$N
     bb <- obj$bb
     mid <- xpos
@@ -25,21 +24,20 @@ if( missing( col)) lwd<- par()$col
         x <- c(x, high, high, high, low, NA, mid, mid, high, 
             low)
         if (horizontal) {
-            lines(y, x, lwd=lwd, col=col)
+            lines(y, x, lwd = lwd, col = col)
         }
         else {
-            lines(x, y,lwd=lwd, col=col)
+            lines(x, y, lwd = lwd, col = col)
         }
     }
     outs <- obj$out
     olen <- length(outs)
     if ((olen > 0) & outlier) {
         if (horizontal) {
-            points(outs, rep(mid, olen), col=col)
+            points(outs, rep(mid, olen), col = col)
         }
         else {
-            points(rep(mid, olen), outs, col=col)
+            points(rep(mid, olen), outs, col = col)
         }
     }
 }
-
