@@ -2,10 +2,8 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"find.upcross" <-
-function (fun, fun.info, upcross.level = 0, guess = 1, tol = 1e-05) 
-{
+"find.upcross" <- function(fun, fun.info, upcross.level = 0, 
+    guess = 1, tol = 1e-05) {
     l1 <- guess
     tr <- 0
     for (k in 1:50) {
