@@ -2,6 +2,6 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"gauss.cov" <-
-function( ...){ Exp.cov(..., p=2)}
+"gauss.cov" <- function(...) {
+    Exp.cov(..., p = 2)
+}
