@@ -2,6 +2,6 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"grey.level" <-
-function( n=256) { grey( seq( 0,1,,n))}
+"grey.level" <- function(n = 256) {
+    grey(seq(0, 1, , n))
+}
