@@ -2,10 +2,7 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"print.qsreg" <-
-function (x, ...) 
-{
+"print.qsreg" <- function(x, ...) {
     digits <- 4
     c1 <- "Number of Observations:"
     c2 <- (x$N)
@@ -14,7 +11,7 @@ function (x, ...)
     c1 <- c(c1, "Residual degrees of freedom:")
     c2 <- c(c2, format(round(x$N - x$trace[x$ind.cv.ps], 1)))
     c1 <- c(c1, "Log10(lambda) ")
-lambda<- x$cv.grid[,1]
+    lambda <- x$cv.grid[, 1]
     c2 <- c(c2, format(round(log10(lambda[x$ind.cv.ps]), 2)))
     sum <- cbind(c1, c2)
     dimnames(sum) <- list(rep("", dim(sum)[1]), rep("", dim(sum)[2]))
