@@ -2,26 +2,22 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"print.summary.Krig" <-
-function (x, ...) 
-{
+"print.summary.Krig" <- function(x, ...) {
     digits <- x$digits
     c1 <- "Number of Observations:"
     c2 <- x$num.observation
     c1 <- c(c1, "Number of unique points:")
     c2 <- c(c2, x$num.uniq)
-#
-# print out null space poly info only if "m" is used
-    
-    if( !is.null( x$args.null$m) ) {
-    c1 <- c(c1, "Degree of polynomial null space ( base model):")
-    c2 <- c(c2, x$m - 1) }
-    
+    #
+    # print out null space poly info only if 'm' is used
+    if (!is.null(x$args.null$m)) {
+        c1 <- c(c1, "Degree of polynomial null space ( base model):")
+        c2 <- c(c2, x$m - 1)
+    }
     c1 <- c(c1, "Number of parameters in the null space")
     c2 <- c(c2, x$nt)
-    c1<- c( c1, "Parameters for fixed spatial drift")
-    c2<- c( c2, x$df.drift)
+    c1 <- c(c1, "Parameters for fixed spatial drift")
+    c2 <- c(c2, x$df.drift)
     c1 <- c(c1, "Effective degrees of freedom:")
     c2 <- c(c2, format(round(x$enp, 1)))
     c1 <- c(c1, "Residual degrees of freedom:")
@@ -47,7 +43,6 @@ function (x, ...)
     res.quantile <- x$res.quantile
     names(res.quantile) <- c("min", "1st Q", "median", "3rd Q", 
         "max")
-
     cat("CALL:\n")
     dput(x$call)
     print(sum, quote = FALSE)
@@ -56,38 +51,34 @@ function (x, ...)
     print(signif(res.quantile, digits))
     cat("\n")
     cat("Covariance Model:", x$cov.function, fill = TRUE)
-
-    if( x$cov.function=="stationary.cov"){
-         cat( "  Covariance function is ", x$args$Covariance, fill=TRUE)}
-
-    if( !is.null(x$args)){ 
-         cat("  Names of non-default covariance arguments: ", fill=TRUE)
-         cat("      ",   
-               paste( as.character(names( x$args)), collapse=", "),
-                  fill=TRUE)}
-
+    if (x$cov.function == "stationary.cov") {
+        cat("  Covariance function is ", x$args$Covariance, fill = TRUE)
+    }
+    if (!is.null(x$args)) {
+        cat("  Names of non-default covariance arguments: ", 
+            fill = TRUE)
+        cat("      ", paste(as.character(names(x$args)), collapse = ", "), 
+            fill = TRUE)
+    }
     if ((x$correlation.model)) {
-        cat(" A correlation model was fit: 
-           Y is standardized before spatial estimate is found", 
-                      fill = TRUE) }
-
+        cat(" A correlation model was fit:\nY is standardized before spatial estimate is found", 
+            fill = TRUE)
+    }
     if (x$knot.model) {
-        cat(" Knot model: ", x$np- x$nt, " knots supplied to define basis 
-                functions", fill = TRUE)}
-
+        cat(" Knot model: ", x$np - x$nt, " knots supplied to define basis\nfunctions", 
+            fill = TRUE)
+    }
     cat("\n")
     cat("DETAILS ON SMOOTHING PARAMETER:", fill = TRUE)
     cat(" Method used:  ", x$method, "   Cost: ", x$cost, fill = TRUE)
     print(x$sum.gcv.lambda, digits = digits)
     cat("\n")
     cat(" Summary of all estimates found for lambda", fill = TRUE)
-
-    if( !is.na( x$lambda.est[1])){
-          print(x$lambda.est, digits = x$digits)}
-      else{
-        cat( x$lambda, " supplied by user", fill=TRUE)}
-
-
+    if (!is.na(x$lambda.est[1])) {
+        print(x$lambda.est, digits = x$digits)
+    }
+    else {
+        cat(x$lambda, " supplied by user", fill = TRUE)
+    }
     invisible(x)
 }
-
