@@ -2,10 +2,7 @@
 # Copyright 2004-2007, Institute for Mathematics Applied Geosciences
 # University Corporation for Atmospheric Research
 # Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
-"surface.surface" <-
-function (obj, ...) 
-{
-# 
-    plot.surface(obj,...)
+"surface.surface" <- function(obj, ...) {
+    #
+    plot.surface(obj, ...)
 }
