@@ -6,6 +6,7 @@
 library( fields)
 options( echo=FALSE)
 set.seed( 234)
+test.for.zero.flag<- 1
 n <- 5
 m <- 4
 mat <- array(rnorm(n*m),c(n,m))
@@ -17,7 +18,6 @@ test.for.zero( mat2 %*% mat, mat2%d*%mat, tol=1e-8 )
 
 test.for.zero( (diag(vec)%*% mat), (vec%d*%mat), tol=1e-8 )
 
-test.for.zero (mat2 %*% vec, mat2%d*%vec, tol=1e-8 )
 
 test.for.zero( diag(vec)%*% vec2, vec%d*%vec2,tol=1e-8)
 cat("All done with testing diag multiply", fill=TRUE)
